Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Hand ¶
type Hand interface {
// Returns the best possible HandRank given a hand & table combination
BestHand() (*HandRank, error)
}
A hand consists of a number of hole cards and a number of board cards.
type HandRank ¶
type HandRank struct {
// The type of the hand rank
RankType RankType
// A list of the ranks of the cards in the hands, in sorted order
// of importance
//
// Only important ranks will be given. For example, straights will
// only have the highest card, and quads will only give the quaded
// card and the kicker.
Ranks []card.Rank
}
type SimpleHandImpl ¶
type SimpleHandImpl struct {
// contains filtered or unexported fields
}
A rudimentary way of calculating the best hand on the board
func NewSimpleHandEvaluator ¶
func NewSimpleHandEvaluator(hole []card.Card, community []card.Card) *SimpleHandImpl
Creates a new simple hand evaluator
func (*SimpleHandImpl) BestHand ¶
func (h *SimpleHandImpl) BestHand() (*HandRank, error)
Click to show internal directories.
Click to hide internal directories.